export BASE_DIR=/data
export ANDROID_NDK=$BASE_DIR/android-ndk-r10e
export ANDROID_SDK_ROOT=$BASE_DIR/sdk-tools-linux-4333796
export Qt5_android=$BASE_DIR/Qt/5.11.2/android_armv7
export PATH=$BASE_DIR/sdk-tools-linux-4333796/platform-tools/:$PATH
export ANT=/usr/bin/ant
export JAVA_HOME=/usr/lib/jvm/java-8-openjdk/
export INSTALL_DIR=/home/pdv/install-dir/usr
export CMAKE_SYSROOT=$BASE_DIR/android-ndk-r10e/platforms/android-17/arch-arm/
